@@ -2,8 +2,8 @@ use std::fmt::{Debug, Formatter};
 use std::ops::{Deref, DerefMut};
 
 use async_trait::async_trait;
-use bson2::Bson;
-use bson2::spec::BinarySubtype;
+use rbson::Bson;
+use rbson::spec::BinarySubtype;
 use futures::Future;
 use rbatis_core::db::DBExecResult;
 use serde::de::DeserializeOwned;
@@ -169,8 +169,8 @@ impl RbatisRef for Rbatis {
 
 #[async_trait]
 pub trait ExecutorMut: RbatisRef {
-    async fn exec(&mut self, sql: &str, args: Vec<bson2::Bson>) -> Result<DBExecResult, Error>;
-    async fn fetch<T>(&mut self, sql: &str, args: Vec<bson2::Bson>) -> Result<T, Error> where T: DeserializeOwned;
+    async fn exec(&mut self, sql: &str, args: Vec<rbson::Bson>) -> Result<DBExecResult, Error>;
+    async fn fetch<T>(&mut self, sql: &str, args: Vec<rbson::Bson>) -> Result<T, Error> where T: DeserializeOwned;
 }
 
 #[derive(Debug)]
@@ -207,7 +207,7 @@ fn bson_arr_to_string(arg: Vec<Bson>) -> (Vec<Bson>, String) {
 
 #[async_trait]
 impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
-    async fn exec(&mut self, sql: &str, mut args: Vec<bson2::Bson>) -> Result<DBExecResult, Error> {
+    async fn exec(&mut self, sql: &str, mut args: Vec<rbson::Bson>) -> Result<DBExecResult, Error> {
         let rb_task_id = new_snowflake_id();
         let mut sql = sql.to_string();
         let is_prepared = args.len() > 0;
@@ -249,7 +249,7 @@ impl<'a> ExecutorMut for RBatisConnExecutor<'_> {
         return result;
     }
 
-    async fn fetch<T>(&mut self, sql: &str, mut args: Vec<bson2::Bson>) -> Result<T, Error> where T: DeserializeOwned {
+    async fn fetch<T>(&mut self, sql: &str, mut args: Vec<rbson::Bson>) -> Result<T, Error> where T: DeserializeOwned {
         let rb_task_id = new_snowflake_id();
         let mut sql = sql.to_string();
         let is_prepared = args.len() > 0;
@@ -336,7 +336,7 @@ impl<'a, 'b> RBatisTxExecutor<'b> {
 
 #[async_trait]
 impl<'a> ExecutorMut for RBatisTxExecutor<'_> {
-    async fn exec(&mut self, sql: &str, mut args: Vec<bson2::Bson>) -> Result<DBExecResult, Error> {
+    async fn exec(&mut self, sql: &str, mut args: Vec<rbson::Bson>) -> Result<DBExecResult, Error> {
         let mut sql = sql.to_string();
         let is_prepared = args.len() > 0;
         for item in &self.get_rbatis().sql_intercepts {
@@ -377,7 +377,7 @@ impl<'a> ExecutorMut for RBatisTxExecutor<'_> {
         return result;
     }
 
-    async fn fetch<T>(&mut self, sql: &str, mut args: Vec<bson2::Bson>) -> Result<T, Error> where T: DeserializeOwned {
+    async fn fetch<T>(&mut self, sql: &str, mut args: Vec<rbson::Bson>) -> Result<T, Error> where T: DeserializeOwned {
         let mut sql = sql.to_string();
         let is_prepared = args.len() > 0;
         for item in &self.get_rbatis().sql_intercepts {
@@ -544,7 +544,7 @@ impl<'a> RBatisTxExecutor<'a> {
     pub async fn fetch_page<T>(
         &self,
         sql: &str,
-        args: Vec<bson2::Bson>,
+        args: Vec<rbson::Bson>,
         page_request: &dyn IPageRequest,
     ) -> crate::Result<Page<T>>
         where
@@ -583,8 +583,8 @@ impl Drop for RBatisTxExecutorGuard<'_> {
 
 #[async_trait]
 pub trait Executor: RbatisRef {
-    async fn exec(&self, sql: &str, args: Vec<bson2::Bson>) -> Result<DBExecResult, Error>;
-    async fn fetch<T>(&self, sql: &str, args: Vec<bson2::Bson>) -> Result<T, Error> where T: DeserializeOwned;
+    async fn exec(&self, sql: &str, args: Vec<rbson::Bson>) -> Result<DBExecResult, Error>;
+    async fn fetch<T>(&self, sql: &str, args: Vec<rbson::Bson>) -> Result<T, Error> where T: DeserializeOwned;
 }
 
 #[async_trait]
