@@ -162,6 +162,17 @@ impl Wrapper {
         return self;
     }
 
+    /// do method,if test is true
+    /// for example:
+    ///  let arg = 1;
+    ///  wrapper.r#if(true, |w| w.eq("id"))
+    pub fn r#if<'s, F>(self, test: bool, method: F) -> Self
+        where
+            F: FnOnce(Self) -> Self,
+    {
+        self.do_if(test,method)
+    }
+
     /// do method,if test is true
     /// for example:
     ///  let arg = 1;
@@ -177,6 +188,17 @@ impl Wrapper {
         }
     }
 
+    /// do method,if test is true
+    /// for example:
+    ///  let arg = 1;
+    ///  wrapper.do_if(true, |w| w.eq("id"),|w|w)
+    pub fn r#if_else<'s, F>(self, test: bool, method_if: F, method_else: fn(Self) -> Self) -> Self
+        where
+            F: FnOnce(Self) -> Self,
+    {
+        self.do_if_else(test,method_if,method_else)
+    }
+
     ///match cases
     /// for example:
     ///  let p = Option::<i32>::Some(1);
@@ -724,7 +746,7 @@ impl Wrapper {
             );
         } else {
             self.sql = format!(
-                "{} {} ({}) {} {}",
+                "{} {} ({}) {} ({})",
                 crate::sql::TEMPLATE.insert_into.value,
                 table_name,
                 columns,
